import { isValidElement } from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types/index.js';
import { FIELDS } from '../Standard/index.js'; // fields

import TextField from '../Standard/Fields/Text/index.js';
import NumericField from '../Standard/Fields/Numeric/index.js';
import FieldSetField from '../Standard/Fields/FieldSet/index.js';
import PickerField from '../Standard/Fields/Picker/index.js';
import MultiPickerField from '../Standard/Fields/Multicheckbox/index.js';
import RangeField from '../Standard/Fields/Range/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var ProxyField = function ProxyField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var Field;

  switch (field.type) {
    case FIELDS.TEXT:
      Field = TextField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.NUMERIC:
      Field = NumericField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.FIELDSET:
      Field = FieldSetField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.PICKER:
      Field = PickerField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.MULTIPICKER:
      Field = MultiPickerField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.RANGE:
      Field = RangeField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onFocus: onFocus,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    default:
      {
        var rendererResponse = renderer({
          id: field.id,
          innerProps: {
            field: field,
            tabIndex: tabIndex,
            onChange: onChange,
            onFocus: onFocus,
            onBlur: onBlur,
            errors: errors,
            alerts: alerts
          }
        });

        if ( /*#__PURE__*/isValidElement(rendererResponse)) {
          Field = rendererResponse;
        } else {
          Field = /*#__PURE__*/_jsxs("p", {
            children: ["Unknown Field type ", /*#__PURE__*/_jsx("span", {
              children: field.type
            })]
          });
        }

        break;
      }
  }

  return Field;
};

ProxyField.displayName = 'ProxyField';
export default ProxyField;